==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebRippleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRippleDescription } from "./WebRippleDescription";
/**
 * @hidden
 */
export let WebRippleDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRippleDescriptionMetadata extends Base {
        static b(a) {
            if (WebRippleDescriptionMetadata.a == null) {
                WebRippleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRippleDescriptionMetadata.c(WebRippleDescriptionMetadata.a);
            }
            if (a.j(WebRippleDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRippleDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Ripple");
            a.item("__tagNameWC", "String:igc-ripple");
        }
        static d(a) {
            WebRippleDescriptionMetadata.b(a);
            a.aa("WebRipple", () => new WebRippleDescription());
            a.z("WebRipple", WebRippleDescriptionMetadata.a);
        }
    }
    WebRippleDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRippleDescriptionMetadata, 'WebRippleDescriptionMetadata');
    WebRippleDescriptionMetadata.a = null;
    return WebRippleDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRippleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRippleDescription } from "./WebRippleDescription";
/**
 * @hidden
 */
export let WebRippleDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRippleDescriptionMetadata extends Base {
        static b(a) {
            if (WebRippleDescriptionMetadata.a == null) {
                WebRippleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRippleDescriptionMetadata.c(WebRippleDescriptionMetadata.a);
            }
            if (a.k(WebRippleDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRippleDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Ripple");
            a.item("__tagNameWC", "String:igc-ripple");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebRippleDescriptionMetadata.b(a);
            a.ac("WebRipple", () => new WebRippleDescription());
            a.ab("WebRipple", WebRippleDescriptionMetadata.a);
        }
    }
    WebRippleDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRippleDescriptionMetadata, 'WebRippleDescriptionMetadata');
    WebRippleDescriptionMetadata.a = null;
    return WebRippleDescriptionMetadata;
})();
